CsvFieldConvertToString Delegate

Definition

Namespace: DataStandardizer.File.CSV

The delegate called to serialize a property value into a raw CSV field value when writing.

Syntax

public delegate string CsvFieldConvertToString<TModel>(CsvFieldContext<TModel> context)
    where TModel : class;

Remarks

Attached to a mapping with the ConvertUsing step of the fluent CsvFieldMappingBuilder. Read the model value from the context and return the string to write. See CsvFieldContext.

Applies to

Targets netstandard1.3, netstandard2.0, net8.0, and net10.0.

See also

</content>


This site uses Just the Docs, a documentation theme for Jekyll.