CsvFieldConvertFromString Delegate
Definition
Namespace: DataStandardizer.File.CSV
The delegate called to deserialize a raw CSV field value into a property value when reading. T is covariant.
Syntax
public delegate T CsvFieldConvertFromString<TModel, out T>(CsvFieldContext<TModel> context)
where TModel : class;
Remarks
Attached to a mapping with the ConvertUsing step of the fluent CsvFieldMappingBuilder. Read the raw value from the context and return the converted property value. See CsvFieldContext.
Applies to
Targets netstandard1.3, netstandard2.0, net8.0, and net10.0.
See also
</content>